==> cscec5b-fbxt-api-3.0.1-20230526.005839-115-sources.jar: com/ejianc/business/fbxt/odd/vo/OddInfoApplyVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 用工申请清单实体
 *
 * @author generator
 *
 */
public class OddInfoApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long oddApplyId; // 用工申请主键
    private String name; // 清单名称
    private java.math.BigDecimal num; // 申请数量
    private java.math.BigDecimal price; // 无税单价
    private java.math.BigDecimal mny; // 金额
    private String code; // 清单编码
    private String infoUnit; // 单位
    private java.math.BigDecimal reviewNum; // 审核数量
    private java.math.BigDecimal reviewPrice; // 审核单价
    private java.math.BigDecimal reviewMny; // 审核金额
    private Integer sourceType; // 来源类型，0--引用，1-手工新增
    private String sourceId; // 来源主键
    private String pkMeasdoc; // 单位主键


    /**
     * 用工申请主键
     */
    public Long getOddApplyId() {
        return oddApplyId;
    }

    /**
     * 用工申请主键
     */
    public void setOddApplyId(Long oddApplyId) {
        this.oddApplyId = oddApplyId;
    }
    /**
     * 清单名称
     */
    public String getName() {
        return name;
    }

    /**
     * 清单名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 申请数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 申请数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 清单编码
     */
    public String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 单位
     */
    public String getInfoUnit() {
        return infoUnit;
    }

    /**
     * 单位
     */
    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }
    /**
     * 审核数量
     */
    public java.math.BigDecimal getReviewNum() {
        return reviewNum;
    }

    /**
     * 审核数量
     */
    public void setReviewNum(java.math.BigDecimal reviewNum) {
        this.reviewNum = reviewNum;
    }
    /**
     * 审核单价
     */
    public java.math.BigDecimal getReviewPrice() {
        return reviewPrice;
    }

    /**
     * 审核单价
     */
    public void setReviewPrice(java.math.BigDecimal reviewPrice) {
        this.reviewPrice = reviewPrice;
    }
    /**
     * 审核金额
     */
    public java.math.BigDecimal getReviewMny() {
        return reviewMny;
    }

    /**
     * 审核金额
     */
    public void setReviewMny(java.math.BigDecimal reviewMny) {
        this.reviewMny = reviewMny;
    }
    /**
     * 来源类型，0--引用，1-手工新增
     */
    public Integer getSourceType() {
        return sourceType;
    }

    /**
     * 来源类型，0--引用，1-手工新增
     */
    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getPkMeasdoc() {
        return pkMeasdoc;
    }

    public void setPkMeasdoc(String pkMeasdoc) {
        this.pkMeasdoc = pkMeasdoc;
    }
}

==> cscec5b-fbxt-api-3.0.1-20240221.074023-183-sources.jar: com/ejianc/business/fbxt/odd/vo/OddInfoApplyVO.java <==
package com.ejianc.business.fbxt.odd.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import java.util.Map;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 用工申请清单实体
 *
 * @author generator
 *
 */
public class OddInfoApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long oddApplyId; // 用工申请主键
    private String name; // 清单名称
    private java.math.BigDecimal num; // 申请数量
    private java.math.BigDecimal price; // 无税单价
    private java.math.BigDecimal mny; // 金额
    private String code; // 清单编码
    private String infoUnit; // 单位
    private Map<Object,Object> measdocRef; // 参照单位
    private java.math.BigDecimal reviewNum; // 审核数量
    private java.math.BigDecimal reviewPrice; // 审核单价
    private java.math.BigDecimal reviewMny; // 审核金额
    private Integer sourceType; // 来源类型，0--引用，1-手工新增
    private String sourceId; // 来源主键
    private String pkMeasdoc; // 单位主键


    public Map<Object, Object> getMeasdocRef() {
        return measdocRef;
    }

    public void setMeasdocRef(Map<Object, Object> measdocRef) {
        this.measdocRef = measdocRef;
    }

    /**
     * 用工申请主键
     */
    public Long getOddApplyId() {
        return oddApplyId;
    }

    /**
     * 用工申请主键
     */
    public void setOddApplyId(Long oddApplyId) {
        this.oddApplyId = oddApplyId;
    }
    /**
     * 清单名称
     */
    public String getName() {
        return name;
    }

    /**
     * 清单名称
     */
    public void setName(String name) {
        this.name = name;
    }
    /**
     * 申请数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 申请数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 无税单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 无税单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 清单编码
     */
    public String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(String code) {
        this.code = code;
    }
    /**
     * 单位
     */
    public String getInfoUnit() {
        return infoUnit;
    }

    /**
     * 单位
     */
    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }
    /**
     * 审核数量
     */
    public java.math.BigDecimal getReviewNum() {
        return reviewNum;
    }

    /**
     * 审核数量
     */
    public void setReviewNum(java.math.BigDecimal reviewNum) {
        this.reviewNum = reviewNum;
    }
    /**
     * 审核单价
     */
    public java.math.BigDecimal getReviewPrice() {
        return reviewPrice;
    }

    /**
     * 审核单价
     */
    public void setReviewPrice(java.math.BigDecimal reviewPrice) {
        this.reviewPrice = reviewPrice;
    }
    /**
     * 审核金额
     */
    public java.math.BigDecimal getReviewMny() {
        return reviewMny;
    }

    /**
     * 审核金额
     */
    public void setReviewMny(java.math.BigDecimal reviewMny) {
        this.reviewMny = reviewMny;
    }
    /**
     * 来源类型，0--引用，1-手工新增
     */
    public Integer getSourceType() {
        return sourceType;
    }

    /**
     * 来源类型，0--引用，1-手工新增
     */
    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getPkMeasdoc() {
        return pkMeasdoc;
    }

    public void setPkMeasdoc(String pkMeasdoc) {
        this.pkMeasdoc = pkMeasdoc;
    }
}
